@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.88';
+$Geo::Address::Formatter::VERSION = '1.89';
 use strict;
 use warnings;
 use feature qw(say);
@@ -32,20 +32,25 @@ sub new {
     $self->{final_components} = undef;
     bless($self, $class);
 
-    $self->_read_configuration($conf_path);
-    return $self;
+    if ($self->_read_configuration($conf_path)){
+        return $self;
+    }
+    die 'unable to read configuration';
 }
 
 sub _read_configuration {
     my $self = shift;
     my $path = shift;
 
+    return if (! -e $path);
+
     my @a_filenames = File::Find::Rule->file()->name('*.yaml')->in($path . '/countries');
 
     $self->{templates}         = {};
     $self->{component_aliases} = {};
 
     # read the config file(s)
+    my $loaded = 0;
     foreach my $filename (sort @a_filenames) {
         try {
             my $rh_templates = LoadFile($filename);
@@ -56,14 +61,18 @@ sub _read_configuration {
             foreach (keys %$rh_templates) {
                 $self->{templates}{$_} = $rh_templates->{$_};
             }
+            $loaded = 1;
         } catch {
             warn "error parsing country configuration in $filename: $_";
         };
     }
+    return if ($loaded == 0);
 
     # see if we can load the components
     try {
+        say STDERR "loading components" if ($debug);
         my @c = LoadFile($path . '/components.yaml');
+        #say STDERR Dumper \@c;
 
         foreach my $rh_c (@c) {
             if (defined($rh_c->{aliases})) {
@@ -116,7 +125,7 @@ sub _read_configuration {
     }
     #say Dumper $self->{abbreviations};
     #say Dumper $self->{country2lang};
-    return;
+    return 1;
 }
 
 
@@ -196,6 +205,11 @@ sub format_address {
 
     # add the attention, but only if needed
     my $ra_unknown = $self->_find_unknown_components($rh_components);
+    if ($debug){
+        say STDERR "unknown_components:";
+        say STDERR Dumper $ra_unknown;
+    }
+
     if (scalar(@$ra_unknown)) {
         $rh_components->{attention} = join(', ', map { $rh_components->{$_} } @$ra_unknown);
     }
@@ -715,7 +729,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.88
+version 1.89
 
 =head1 SYNOPSIS
 
